@@ -1,7 +1,7 @@
-"""This package provides classes, types, and functions to control Digilent measurement and test devices."""
+"""This package provides classes, types, and functions to control Digilent Waveforms devices."""
 
 # The version number of the *pydwf* package.
-__version__ = "0.6.3"
+__version__ = "0.6.8"
 
 # The *DwfLibrary* type is the only type users need to access library functionality.
 from pydwf.core.dwf_library import DwfLibrary
