@@ -14,13 +14,17 @@ from pydwf.core.api.device_control import DeviceControl
 
 class DwfLibrary:
     """The |DwfLibrary| class provides access to miscellaneous DWF functions, and to |device enumeration:link| and
-    |device control:link| functionality via its |deviceEnum:link| and |deviceControl:link| attributes:
+    |device control:link| functionality via its |deviceEnum:link| and |deviceControl:link| attributes.
+
+    .. rubric:: |DwfLibrary| attributes
 
     Attributes:
         deviceEnum (DeviceEnumeration):
             Provides access to the |device enumeration:link| functionality.
         deviceControl (DeviceControl):
             Provides access to the |device control:link| functionality.
+
+    .. rubric:: |DwfLibrary| methods
     """
 
     def __init__(self, check_library_version: bool = True) -> None:
