@@ -7,15 +7,17 @@ from pydwf.core.dwf_device import DwfDevice
 from pydwf.core.auxiliary.enum_types import DwfEnumConfigInfo, DwfEnumFilter
 from pydwf.core.auxiliary.exceptions import PyDwfError
 
-def open_dwf_device(dwf: DwfLibrary, serial_number:Optional[str]=None,
-                    configuration_fitness_func:Optional[Callable]=None,
-                    enum_filter: DwfEnumFilter=DwfEnumFilter.All) -> DwfDevice:
+
+def open_dwf_device(dwf: DwfLibrary, serial_number: Optional[str] = None,
+                    configuration_fitness_func: Optional[Callable] = None,
+                    enum_filter: DwfEnumFilter = DwfEnumFilter.All) -> DwfDevice:
     """Open a device identified by its serial number, optionally selecting a preferred configuration.
 
     Note:
         This method takes several seconds to complete.
 
     Parameters:
+        dwf (DwfLibrary): The |DwfLibrary:link| used to open the device.
         serial_number (str): The serial number of the device to be opened.
             Digilent Waveforms device serial numbers consist of 12 hexadecimal digits.
         configuration_fitness_func (Callable):
@@ -24,17 +26,18 @@ def open_dwf_device(dwf: DwfLibrary, serial_number:Optional[str]=None,
             An optional filter to limit the device enumeration to certain device types.
 
     Returns:
-        DwfDevice: The |DwfDevice| created as a result of this call.
+        DwfDevice: The |DwfDevice:link| created as a result of this call.
 
     Raises:
         PyDwfError: could not select a unique candidate device.
     """
 
     # The dwf.deviceEnum.enumerateDevices() function builds an internal table of connected devices
-    # that can be queried using other dwf.enumumeration methods.
+    # that can be queried using other dwf.deviceEnum methods.
     num_devices = dwf.deviceEnum.enumerateDevices(enum_filter)
 
-    candidate_devices = [device_index for device_index in range(num_devices)]  # pylint: disable=unnecessary-comprehension # (we need it to satisfy mypy)
+    # We do the explicit conversion to list to make sure the variable is a list of integers, not a range.
+    candidate_devices = list(range(num_devices))
 
     if serial_number is not None:
 
@@ -56,9 +59,10 @@ def open_dwf_device(dwf: DwfLibrary, serial_number:Optional[str]=None,
             raise PyDwfError("No Digilent Waveforms devices found in device class '{}'.".format(enum_filter.name))
 
         if len(candidate_devices) > 1:
-            raise PyDwfError("Multiple Digilent Waveforms devices found (serial numbers: {});"
-                             " specify a serial number to select one.".format(
-                ", ".join(dwf.deviceEnum.serialNumber(device_index) for device_index in candidate_devices)))
+            raise PyDwfError(
+                "Multiple Digilent Waveforms devices found (serial numbers: {});"
+                " specify a serial number to select one.".format(
+                    ", ".join(dwf.deviceEnum.serialNumber(device_index) for device_index in candidate_devices)))
 
     # We now have a single candidate device left.
 
@@ -75,13 +79,13 @@ def open_dwf_device(dwf: DwfLibrary, serial_number:Optional[str]=None,
 
     num_config = dwf.deviceEnum.enumerateConfigurations(device_index)
 
-    best_configuration_index   = None
+    best_configuration_index = None
     best_configuration_fitness = None
 
     for configuration_index in range(num_config):
 
         configuration_info = {
-            configuration_parameter.name :
+            configuration_parameter.name:
                 dwf.deviceEnum.configInfo(configuration_index, configuration_parameter)
             for configuration_parameter in DwfEnumConfigInfo}
 
